package com.fluentadflowreactnativesdk

import android.os.Handler
import android.os.Looper
import android.util.Log
import com.facebook.react.bridge.Promise
import com.facebook.react.bridge.ReactApplicationContext
import com.facebook.react.bridge.ReactContextBaseJavaModule
import com.facebook.react.bridge.ReactMethod
import com.fluent.adflowsdk.adflow.AdvertisingManager
import java.util.concurrent.Executors

class AdvertisingManager(reactContext: ReactApplicationContext) : ReactContextBaseJavaModule(reactContext) {

    override fun getName(): String {
        return "AdvertisingManager"
    }

    @ReactMethod
fun retrieveGAIDIfAvailable(promise: Promise) {
    val context = reactApplicationContext
    Log.d("AdvertisingManager", "Starting retrieveGAIDIfAvailable")

    // If GAID has already been retrieved, resolve the promise immediately
    val existingGAID = AdvertisingManager.getGAID()
    if (existingGAID != null) {
        Log.d("AdvertisingManager", "Existing GAID found: $existingGAID")
        promise.resolve(existingGAID)
        return
    }

    // Retrieve GAID in a background thread
    Executors.newSingleThreadExecutor().execute {
        try {
            AdvertisingManager.retrieveGAIDIfAvailable(context, object : AdvertisingManager.GAIDCallback {
                override fun onGAIDRetrieved(gaid: String?) {
                    Log.d("AdvertisingManager", "GAID retrieved: $gaid")
                    Handler(Looper.getMainLooper()).post {
                        promise.resolve(gaid ?: "") // Resolve with GAID or empty string if unavailable
                    }
                }
            })
        } catch (e: Exception) {
            Log.e("AdvertisingManager", "Error retrieving GAID", e)
            promise.reject("GAID_ERROR", e) // Reject with an error if retrieval fails
        }
    }
  }
}
