import { NativeModules, Platform } from 'react-native';
import { FluentAdFlowWidgetView } from './fluent-adflow-widget';

// Access the native module for FluentAdFlowAdsSdk
const FluentAdFlowSdk = NativeModules.FluentAdFlowAdsSdk
  ? NativeModules.FluentAdFlowAdsSdk
  : new Proxy(
      {},
      {
        get() {},
      }
    );

// Access the native AdvertisingManager directly
const AdvertisingManager = NativeModules.AdvertisingManager
  ? NativeModules.AdvertisingManager
  : new Proxy(
      {},
      {
        get() {},
      }
    );

export class FluentAdFlowWidget {
  static retrieveIDFA = async () => {
    console.log('----------- retrieveIDFA method -----------');
    try {
      const idfa = await FluentAdFlowWidget.getAdvertisingId();
      console.log('Retrieved IDFA:', idfa);
    } catch (error) {
      //console.error('Error retrieving IDFA from App.tsx:', error);
    }
  };

  static init(apiKey: string, referer?: string) {
    FluentAdFlowWidget.retrieveIDFA();
    return FluentAdFlowSdk.initSdk(apiKey, referer);
  }

  static getAdvertisingId(): Promise<string | null> {
    return new Promise((resolve) => {
      if (Platform.OS === 'android') {
        console.log('------------- Android GAID retrieving ----------------');
        AdvertisingManager.retrieveGAIDIfAvailable()
          .then((gaid: string) => {
            console.log('------------- Android GAID:', gaid);
            resolve(gaid || null); // Resolve with GAID or null
          })
          .catch((error: Error) => {
            console.error('Error retrieving GAID:', error);
            resolve(null); // Resolve with null in case of an error
          });
      } else if (Platform.OS === 'ios') {
        console.log('------------- iOS IDFA retrieving ----------------');
        AdvertisingManager.requestTrackingPermissionIfAvailable()
          .then((idfa: string) => {
            console.log('------------- iOS IDFA:', idfa);
            resolve(idfa || null);
          })
          .catch((error: Error) => {
            console.error('Error retrieving IDFA:', error);
            resolve(null);
          });
      } else {
        console.error('Unsupported platform');
        resolve(null);
      }
    });
  }
}

export { FluentAdFlowWidgetView };
